EmvParser class

String analizer

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defineChannel(String channel) EmvChannelType
Determina el type para el canal que realizó la petición para generar el QR (generador del QR)
defineCondition(String condition, int ivaPercent) EmvConditionType?
PARA IVA: Depende del valor o porcentaje del IVA. PARA INC: Depende del valor o porcentaje del INC.
defineGUIType(String gui) EmvGuiType
defineQrType(String value, int monto) EmvQrType
defineRequestedCustomerData(String value) EmvBeRequestedCustomer
Define los datos que deben ser requeridos al consumidor
defineTransacctionType(String value) EmvTransactionType
Determina el propósito de la transacción
parse(String value) List<TLV>
Analiza una cadena siguiendo reglas y devuelve un modelo o estructura con significado