menu
emv_qr_core package
documentation
domain/entities/shared/tlv.dart
TLV class
TLV class
dark_mode
light_mode
TLV
class
TAG LENGTH VALUE: String with substrings
Constructors
TLV
({
required
int
tag
,
required
int
length
,
required
String
value
})
TLV.empty
()
factory
TLV.fromMap
(
Map
<
String
,
dynamic
>
map
)
factory
Properties
hashCode
→
int
The hash code for this object.
no setter
override
length
→
int
final
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
tag
→
int
final
value
→
String
final
Methods
copyWith
(
{
int
?
tag
,
int
?
length
,
String
?
value
})
→
TLV
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson
(
)
→
String
toMap
(
)
→
Map
<
String
,
dynamic
>
toString
(
)
→
String
A string representation of this object.
override
Operators
operator ==
(
covariant
TLV
other
)
→
bool
The equality operator.
override
emv_qr_core package
documentation
domain/entities/shared/tlv
TLV class
tlv library